<?php
/**
 * @package     Joomla.Site
 * @subpackage  Templates.protostar
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

$app             = JFactory::getApplication();
$doc             = JFactory::getDocument();
$user            = JFactory::getUser();
$this->language  = $doc->language;
$this->direction = $doc->direction;

// Getting params from template
$params = $app->getTemplate(true)->params;

// Detecting Active Variables
$option   = $app->input->getCmd('option', '');
$view     = $app->input->getCmd('view', '');
$layout   = $app->input->getCmd('layout', '');
$task     = $app->input->getCmd('task', '');
$itemid   = $app->input->getCmd('Itemid', '');
$sitename = $app->get('sitename');

if($task == "edit" || $layout == "form" )
{
	$fullWidth = 1;
}
else
{
	$fullWidth = 0;
}

// Add JavaScript Frameworks
JHtml::_('bootstrap.framework');
$doc->addScript($this->baseurl . '/templates/' . $this->template . '/js/template.js');

// Add Stylesheets
$doc->addStyleSheet($this->baseurl . '/templates/' . $this->template . '/css/template.css');

// Load optional RTL Bootstrap CSS
JHtml::_('bootstrap.loadCss', false, $this->direction);

// Adjusting content width
if ($this->countModules('jlms-right'))
{
	$span = "span9";
}
else
{
	$span = "span12";
}

// Logo file or site title param
if ($this->params->get('logoFile'))
{
	$logo = '<img src="' . JUri::root() . $this->params->get('logoFile') . '" alt="' . $sitename . '" />';
}
elseif ($this->params->get('sitetitle'))
{
	$logo = '<span class="site-title" title="' . $sitename . '">' . htmlspecialchars($this->params->get('sitetitle')) . '</span>';
}
else
{
	$logo = '<span class="site-title" title="' . $sitename . '">' . $sitename . '</span>';
}
?>
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $this->language; ?>" lang="<?php echo $this->language; ?>" dir="<?php echo $this->direction; ?>">
<head>
	<meta name="viewport" content="width=device-width, initial-scale=1.0" />
	<jdoc:include type="head" />
	<?php // Use of Google Font ?>
	<?php if ($this->params->get('googleFont') && 0) : ?>
		<link href='//fonts.googleapis.com/css?family=<?php echo $this->params->get('googleFontName'); ?>' rel='stylesheet' type='text/css' />
		<style type="text/css">
			h1,h2,h3,h4,h5,h6,.site-title{
				font-family: '<?php echo str_replace('+', ' ', $this->params->get('googleFontName')); ?>', sans-serif;
			}
		</style>
	<?php endif; ?>
	<?php // Template color ?>
	<?php if ($this->params->get('templateColor')) : ?>
	<style type="text/css">
		.nav-top
		{
			border-top: 3px solid <?php echo $this->params->get('templateColor'); ?>;
		}
		body.site
		{
			border-top: 0px solid <?php echo $this->params->get('templateColor'); ?>;
			background-color: <?php echo $this->params->get('templateBackgroundColor'); ?>
		}
		a
		{
			color: <?php echo $this->params->get('templateColor'); ?>;
		}
		.navbar-inner, .nav-list > .active > a, .nav-list > .active > a:hover, .dropdown-menu li > a:hover, .dropdown-menu .active > a, .dropdown-menu .active > a:hover, .nav-pills > .active > a, .nav-pills > .active > a:hover,
		.btn-primary
		{
			background: <?php echo $this->params->get('templateColor'); ?>;
		}
		.navbar-inner
		{
			-moz-box-shadow: 0 1px 3px rgba(0, 0, 0, .25), inset 0 -1px 0 rgba(0, 0, 0, .1), inset 0 30px 10px rgba(0, 0, 0, .2);
			-webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, .25), inset 0 -1px 0 rgba(0, 0, 0, .1), inset 0 30px 10px rgba(0, 0, 0, .2);
			box-shadow: 0 1px 3px rgba(0, 0, 0, .25), inset 0 -1px 0 rgba(0, 0, 0, .1), inset 0 30px 10px rgba(0, 0, 0, .2);
		}
		.nav-side {
			background-color: <?php echo $this->params->get('templateColor'); ?>;
		}
		.nav-side ul li a:hover,
		.nav-side ul li a:focus,
		.nav-side ul li a:active {
			color: <?php echo $this->params->get('templateColor'); ?>;
		}
		.nav-side ul li a:hover i,
		.nav-side ul li a:focus i,
		.nav-side ul li a:active i {
			color: <?php echo $this->params->get('templateColor'); ?>;
		}
		.nav-side ul li a:hover .caption,
		.nav-side ul li a:focus .caption,
		.nav-side ul li a:active .caption {
			color: <?php echo $this->params->get('templateColor'); ?>;
		}
		.steps .steps-container .step-block.step-active {
			background-color: <?php echo $this->params->get('templateColor'); ?>;
		}
		.steps .steps-container .step-block.step-active:not(:last-child):after {
			border-left-color: <?php echo $this->params->get('templateColor'); ?>;
		}
		.steps .steps-container .step-block.step-active a{
			background-color: <?php echo $this->params->get('templateColor'); ?>;
		}
		[class^="jlmsicon-"], [class*=" jlmsicon-"]
		{
			color: <?php echo $this->params->get('templateColor'); ?>;
		}
	</style>
	<?php endif; ?>
	<!--[if lt IE 9]>
		<script src="<?php echo JUri::root(true); ?>/media/jui/js/html5.js"></script>
	<![endif]-->
</head>

<body class="site fluid custom teacher <?php echo $option
	. ' view-' . $view
	. ($layout ? ' layout-' . $layout : ' no-layout')
	. ($task ? ' task-' . $task : ' no-task')
	. ($itemid ? ' itemid-' . $itemid : '');
?>">

	<!-- Body -->
	<div class="body">
		<div class="container-fluid">
			<?php if ($this->countModules('jlms-header-title') || $this->countModules('jlms-header-menu') || $this->countModules('jlms-header-profile')) : ?>
			<!-- Top Navigation -->
			
			<nav id="nav" class="navigation nav-top row-fluid custom">
				<div class="nav-top-border-ghost">
				</div>
				<jdoc:include type="modules" name="jlms-header-title" style="no" />
				<div class="nav-main text-right">
					<jdoc:include type="modules" name="jlms-header-menu" style="no" />
					<jdoc:include type="modules" name="jlms-header-profile" style="no" />
				</div>
				<div class="nav-icon text-center">
					<i class="jlmsicon-menu-expand jlms-icon-profile"></i>
				</div>
			</nav>
			<div class="nav-top-fixer">
			<?php endif; ?>
			<?php if ($this->countModules('jlms-top')) : ?>
				<jdoc:include type="modules" name="jlms-top" style="no" />
			<?php endif; ?>
			<?php if ($this->countModules('jlms-pagetitle')) : ?>
				<!-- Header -->
				<jdoc:include type="modules" name="jlms-pagetitle" style="no" />
			<?php endif; ?>
			<?php /*Can use this, if it always shows site title*/ if (0) : ?>
				<header class="header custom" role="banner">
					<div class="header-inner clearfix">
						<a class="brand pull-left" href="<?php echo JUri::root(true); ?>">
							<span class="site-title" title="<?php echo $this->params->get('sitetitle'); ?>"><?php echo $this->params->get('sitetitle'); ?></span>
						</a>
						<div class="header-search pull-right"></div>
					</div>
				</header>
			<?php endif; ?>
			<jdoc:include type="modules" name="jlms-side-nav" style="no" />
			<div class="row-fluid<?php if ($this->countModules('jlms-side-nav') && $user->get('id')) { echo ' custom';} ?>">

				<main id="content" role="main" class="<?php echo $span; ?>">
				<!-- Begin Content -->
				<jdoc:include type="modules" name="jlms-breadcrumbs" style="no" />
				<jdoc:include type="message" />
				<jdoc:include type="component" />
				<jdoc:include type="modules" name="jlms-bottom" style="no" />	
				<!-- End Content -->
				</main>
				<?php if ($this->countModules('jlms-right')) : ?>
				<div id="aside" class="span3">
				<!-- Begin Right Sidebar -->
					<jdoc:include type="modules" name="jlms-right" style="wellCustom" />
				<!-- End Right Sidebar -->
				</div>
				<?php endif; ?>
			</div>
			<?php if ($this->countModules('jlms-header-title') || $this->countModules('jlms-header-menu') || $this->countModules('jlms-header-profile')) : ?>
			</div>
			<?php endif; ?>
			<!-- Footer -->
			<footer class="footer" role="contentinfo">
				<hr>
				<jdoc:include type="modules" name="jlms-footer" style="none" />
				<p class="pull-right">
					<a href="#top" id="back-top">
						<?php echo JText::_('TPL_JLMS_BACKTOTOP'); ?>
					</a>
				</p>
				<p>
					&copy; <?php echo date('Y'); ?> <?php echo $sitename; ?>		
				</p>
			</footer>
		</div>
	</div>
	<jdoc:include type="modules" name="debug" style="none" />
	<script type="text/javascript">
		(function ($) {
			$('.nav-top-fixer').css('min-height',$('.nav-side').height());
			$('.nav.nav-pills.steps').affix({
			  offset: {
				top: 20,
				bottom: function () {
				  return (this.bottom = $('.footer').outerHeight(true))
				}
			  }
			})
			$('#content > .btn-toolbar.control-group.joomlalms-content-toolbar').affix({
			  offset: {
				top:  function () {
				  var coord = $('#content > .btn-toolbar.control-group.joomlalms-content-toolbar').offset();
				  var ajaster = 0;
				  if($(window).width()>=979){
					var ajaster = 40;
				  }
				  console.log(105+ajaster);
				  return (this.top = coord.top-105-ajaster)
				},
				bottom: function () {
				  return (this.bottom = $('.footer').outerHeight(true))
				}
			  }
			});
			$('.show-hide').click(function() {
				$('.nav-side').toggleClass('expanded');
			});

			$('.nav-icon').click(function() {
				$('.nav-top').toggleClass('tablet');
			});

		}(jQuery));
	</script>
</body>
</html>
