<?php
/**
 * User: nester_a
 * Date: 25.06.14
 */

namespace LMS\Libraries\Base;

use LMS\Libraries\ServiceLocator;

class Model extends \JModelList
{
	protected $modelDir;
	
	protected $repository;

	protected $_forms;
	

	public function __construct($options=array())
	{
		$options['dbo'] = isset($options['dbo']) ? $options['dbo'] : ServiceLocator::get('db');

		parent::__construct($options);
		
		$this->addTablePath($this->modelDir . '/tables/');
	}


	public function getName()
	{
		if (empty($this->name))
		{
			$classArr = explode('\\', get_class($this));
			$className = array_pop($classArr); //cat class name from fullpath namespace
			$this->name = strtolower($className);
		}

		return $this->name;
	}

	public function getForm($name = '', $params = array())
	{
		$loadParams = array_merge(array('control' => 'jform', 'load_data' => true), $params);

		return  $this->loadForm('com_joomla_lms.'.$name, $name, $loadParams);
	}

	public function setState($property, $value = null)
	{
		$this->__state_set = true;
		return parent::setState($property, $value);
	}


	protected function getListQuery()
	{
		$stateProperties = $this->getState()->getProperties();
		return $this->repository()->getByFilterQuery($stateProperties);
	}

	protected function _getListCount($query)
	{
		$this->_db->setQuery($query);
		$this->_db->execute();
		
		return $this->_db->getNumRows();
	}

	protected function loadFormData()
	{
		return array();
	}

	protected function loadForm($name, $source = null, $options = array(), $clear = false, $xpath = false)
	{
		// Handle the optional arguments.
		$options['control'] = \JArrayHelper::getValue($options, 'control', false);

		// Create a signature hash.
		$hash = md5($source . serialize($options));

		// Check if we can use a previously loaded form.
		if (isset($this->_forms[$hash]) && !$clear)
		{
			return $this->_forms[$hash];
		}
		// Get the form.
		\JForm::addFormPath(JPATH_COMPONENT . '/libraries' . '/form' . '/' . '/forms');
		\JForm::addFieldPath(JPATH_COMPONENT . '/libraries' . '/form' . '/' . '/fields');
		\JForm::addFormPath($this->modelDir . '/forms');
		\JForm::addFieldPath($this->modelDir . '/forms/fields');

		try
		{
			$form = \JForm::getInstance($name, $source, $options, false, $xpath);
//			$form = Libraries\ServiceLocator::get('Form', array($name, $source, $options, false, $xpath));

			if (isset($options['load_data']) && $options['load_data'])
			{
				// Get the data for the form.
				$data = $this->loadFormData();
			}
			else
			{
				$data = array();
			}

			// Allow for additional modification of the form, and events to be triggered.
			// We pass the data because plugins may require it.
			$this->preprocessForm($form, $data);

			//tmp fix
			if(is_object($data) && $data instanceof \LMS\Libraries\Database\Object){
				$data = get_object_vars($data);
			}

			// Load the data into the form after the plugins have operated.
			$form->bind($data);

		}
		catch (\Exception $e)
		{
			$this->setError($e->getMessage());
			return false;
		}

		// Store the form for later.
		$this->_forms[$hash] = $form;

		return $form;
	}

	protected function preprocessForm(\JForm $form, $data, $group = 'content')
	{
		// Import the appropriate plugin group.
		\JPluginHelper::importPlugin($group);

		// Get the dispatcher.
		$dispatcher = \JEventDispatcher::getInstance();

		// Trigger the form preparation event.
		$results = $dispatcher->trigger('onContentPrepareForm', array($form, $data));

		// Check for errors encountered while preparing the form.
		if (count($results) && in_array(false, $results, true))
		{
			// Get the last error.
			$error = $dispatcher->getError();

			if (!($error instanceof \Exception))
			{
				throw new \Exception($error);
			}
		}
	}	
	
	/**
	 * @return \LMS\Libraries\Base\Repository
	 */
	public function repository() {
		return $this->repository;
	}
	
	public function validate($form, $data, $group = null)
	{
		// Filter and validate the form data.
		$data = $form->filter($data);		
		$return = $form->validate($data, $group);

		// Check for an error.
		if ($return instanceof Exception)
		{
			$this->setError($return->getMessage());

			return false;
		}

		// Check the validation results.
		if ($return === false)
		{
			// Get the validation messages from the form.
			foreach ($form->getErrors() as $message)
			{
				$this->setError($message);
			}

			return false;
		}

		return $data;
	}
}