<?php
namespace LMS\Tools\Coursebuilder\Controllers;

use LMS\Libraries\Base;
use LMS\Tools\Courses\Helpers;

defined('_JEXEC') or die;

class Builder extends Base\Controller
{
	protected $modelModule;
	
	public function __construct($config=array())
	{			
		parent::__construct($config);
	}
	
	public function show($config=array())
	{			
		$courseId = $this->config->get('course_id');
				
		$step = $this->input->get('step', '1');
		$get = $this->input->get('get', '');
				
		switch($step) {			
			case 1:
				$this->step1();
			break;
			case 2:
				$this->step2();
			break;
			case 3:
				if($get == 'subscriptions'){
					$this->getSubscriptions();
				} else {
					$this->step3();
				}				
			break;
			case 4:
				$this->step4();
			break;
			case 5:
				$this->step5();
			break;
			case 6:
				$this->step6();
			break;
			default:
				$this->setRedirect(\JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=1&course_id='.$courseId));			
				return;
		}
	}
	
	public function step1() 
	{	
		if(!$this->user->get('id')) {
			$this->setRedirect(\JLMSRoute('index.php?option=com_joomla_lms'));
			return JError::raiseError(401, JText::_('You are not authorized to view this resource'));
		}
		
		require_once(JPATH_COMPONENT.DS.'joomla_lms.courses.php');		
				
		$view = $this->getView('Builder', 'html');
		$view->courseId = $this->config->get('course_id');
		$view->step1();
		
		JLMS_editCourse('com_joomla_lms');
	}
	
	public function step2() 
	{		
		$userId = $this->user->get('id');
		if(!$userId) {
			$this->setRedirect(\JLMSRoute('index.php?option=com_joomla_lms'));
			return JError::raiseError(401, JText::_('You are not authorized to view this resource'));
		}
		
		\JFolder::copy(JPATH_SITE.DS.'components'.DS.'com_joomla_lms'.DS.'assets'.DS.'images'.DS.'userdefault', Helpers\Images::folderPath('images', $userId), '', true);
		
		$courseId = $this->config->get('course_id');
		
		if(!$courseId) {
			$this->setRedirect(\JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=1'));			
			return;
		}
		
		require_once(JPATH_COMPONENT.DS.'joomla_lms.courses.php');
		
		$view = $this->getView('Builder', 'html');	
		$view->courseId = $courseId;
		$view->step2();
		
		JLMS_showCourseSettings('com_joomla_lms');
	}
	
	public function step3() 
	{
		if(!$this->user->get('id')) {
			$this->setRedirect(\JLMSRoute('index.php?option=com_joomla_lms'));
			return JError::raiseError(401, JText::_('You are not authorized to view this resource'));
		}
		
		$wrongDataFormat = $this->input->get('wdf', 0);		
		
		$courseId = $this->config->get('course_id');
					
		if(!$courseId) {
			$this->setRedirect(\JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=1'));			
			return;
		}
		
		$modelCourse = $this->getModel('Course', '\\Tools\\Courses\\Model');	
		$modelSubscription = $this->getModel('Subscription', '\\Tools\\Subscriptions\\Model');
		$modelSubscriptions = $this->getModel('Subscriptions', '\\Tools\\Subscriptions\\Model');		
								
		$this->populateModel($modelSubscription);
		$this->populateModel($modelSubscriptions);				
		
		$modelCourse->setState('course_id', $courseId);
		$view = $this->getView('Builder', 'html');			
		$view->form = $modelCourse->getForm('course', array('load_data' => true));
		$view->courseId = $courseId;
		$view->redirect = \JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=4&course_id='.$courseId);		
		
		$modelSubscriptions->setState('list.limit', 0);
		$modelSubscriptions->setState('course_id', $courseId);								
		$viewSubscriptions = $this->getView('Subscriptions', 'html', '\\Tools\\Subscriptions\\View');	
		$viewSubscriptions->redirect = \JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=3&get=subscriptions&course_id='.$courseId);
		$viewSubscriptions->setModel($modelSubscriptions, true);
		$view->viewSubscriptions = $viewSubscriptions;
		
		$viewSubscription = $this->getView('Subscription', 'html', '\\Tools\\Subscriptions\\View');		
		$viewSubscription->form = $modelSubscription->getForm('subscription', array('load_data' => ($wrongDataFormat)?1:0));
		$viewSubscription->courseId = $courseId;
		$viewSubscription->redirect = \JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=3&get=subscriptions&course_id='.$courseId);
		$viewSubscription->setModel($modelSubscription, true);
		$view->viewSubscription = $viewSubscription;
		
		$view->step3();
	}
	
	public function getSubscriptions() 
	{
		if(!$this->user->get('id')) {
			$this->setRedirect(\JLMSRoute('index.php?option=com_joomla_lms'));
			return JError::raiseError(401, JText::_('You are not authorized to view this resource'));
		}
		
		$wrongDataFormat = $this->input->get('wdf', 0);		
		
		$courseId = $this->config->get('course_id');
					
		if(!$courseId) {
			$this->setRedirect(\JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=1'));			
			return;
		}
					
		$modelSubscriptions = $this->getModel('Subscriptions', '\\Tools\\Subscriptions\\Model');							
		
		$this->populateModel($modelSubscriptions);		
		
		$modelSubscriptions->setState('list.limit', 0);		
		$modelSubscriptions->setState('course_id', $courseId);						
		$viewSubscriptions = $this->getView('Subscriptions', 'html', '\\Tools\\Subscriptions\\View');	
		$viewSubscriptions->redirect = \JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=3&get=subscriptions&course_id='.$courseId);
		$viewSubscriptions->setModel($modelSubscriptions, true);		
		$viewSubscriptions->display();
		exit();
	}
	
	public function step4()
	{
		if(!$this->user->get('id')) {
			$this->setRedirect(\JLMSRoute('index.php?option=com_joomla_lms'));
			return JError::raiseError(401, JText::_('You are not authorized to view this resource'));
		}

		$courseId = $this->config->get('course_id');

		if(!$courseId) {
			$this->setRedirect(\JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=1'));
			return;
		}

		$Itemid = $this->input->get('Itemid', 0);
		$patternId = $this->input->get('pattern_id', 0);
		$reset = $this->input->get('reset', 0);

		$modelLearningPattern = $this->getModel('LearningPattern');
		$modelLearningPattern->setState('courseId', $courseId);
		$modelLearningPattern->setState('patternId', $patternId);
		$modelLearningPattern->setState('reset', $reset);
		
		$this->populateModel($modelLearningPattern);
		
		$view = $this->getView('Builder', 'html');	
		$view->courseId = $courseId;
		$view->step4();		
		
		$viewLP = $this->getView('LearningPattern');	
		$viewLP->setModel($modelLearningPattern, true);
		
		if($Itemid){ 
			$viewLP->Itemid = $Itemid; 
		}		
		
		$viewLP->show();
	}
	
	public function step5()
	{	
		if(!$this->user->get('id')) {
			$this->setRedirect(\JLMSRoute('index.php?option=com_joomla_lms'));
			return JError::raiseError(401, JText::_('You are not authorized to view this resource'));
		}
		
		$courseId = $this->config->get('course_id');

		if(!$courseId) {
			$this->setRedirect(\JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=1'));			
			return;
		}		

		$view = $this->getView('Builder', 'html');	
		$view->courseId = $courseId;
		$view->step5();
		
		$viewSM = $this->getView('SetupModules', 'html');
		$viewSM->show();
	}	
	
	public function step6()
	{	
		if(!$this->user->get('id')) {
			$this->setRedirect(\JLMSRoute('index.php?option=com_joomla_lms'));
			return JError::raiseError(401, JText::_('You are not authorized to view this resource'));
		}
		
		$courseId = $this->config->get('course_id');			

		if(!$courseId) {
			$this->setRedirect(\JLMSRoute::_('index.php?option=com_joomla_lms&task=coursebuilder.builder.show&step=1'));			
			return;
		}		
				
		$view = $this->getView('Builder', 'html');	
		$view->courseId = $courseId;
		$view->step6();	
	}
}