<?php
namespace LMS\Tools\Coursebuilder\Model;

use LMS\Libraries\Base;
use LMS\Libraries\ServiceLocator;
use LMS\Tools\Coursebuilder\Repositories;

defined('_JEXEC') or die;


class LearningPattern extends Base\Model
{
	protected $name = 'LearningPattern';

	protected $savedPatternId;
	protected $currentPatternId;

	public function __construct($options = array())
	{
		parent::__construct($options);
		$this->modelDir = __DIR__;
		$this->repository = isset($options['repository']) ? $options['repository'] : new Repositories\LmsLocalMenu(array('db' => $this->_db));
	}

	public function updateCourseParams()
	{
		$repositoryCourse = ServiceLocator::get('repositoryCourse');
		$course = $repositoryCourse->getByID($this->getState('courseId'));

		$registry = new \JRegistry;
		$registry->loadString($course->params);
		if($this->getState('patternId')){
			$registry->set('pattern_id', $this->getState('patternId'));
		} else {
			$registry->set('pattern_id', 0);
		}
		$paramsString = $registry->toString('INI');

		$updateData = array();
		$updateData['params'] = $paramsString;

		$repositoryCourse->update($updateData, array('id' => $this->getState('courseId')));
	}

	public function save()
	{
		$repositoryExtensions = new Repositories\Extensions();
		$repositoryModulesMenu = new Repositories\ModulesMenu();
		$repositorySystemMenu = new Repositories\SystemMenu();

		$moduleNamesExcludeToDelete = array();
		$libraryConfigLoader = ServiceLocator::get('libraryConfigLoader');
		$configModules = $libraryConfigLoader::getConfigParam('menu_elements.third_level.modules');
		foreach($configModules as $item){
			$moduleNamesExcludeToDelete[] = $item['module_name'];
		}

		$pattern = $this->getPatternById($this->getState('patternId'));
		$modules = $pattern->modules;

		$systemMenuItem = $repositorySystemMenu->getJlmsSystemMenuItemByCourseId($this->getState('courseId'));

		$prevModules = $repositoryModulesMenu->getModulesByMenuItemid($systemMenuItem->item_id);
		$dbModules = array();
		if(isset($prevModules) && count($prevModules)){
			foreach($prevModules as $prevModule){
				if(!in_array($prevModule->module, $moduleNamesExcludeToDelete)){
					$dbModules[] = $prevModule;
				}
			}
		}

		$modulesForSave = array();
		$moduleMenuIdsForDelete = array();
		$moduleIdsForDelete = array();

		$modulesForSave = $modules;
		if(isset($dbModules) && count($dbModules)){
			$modulesForSave = array();
			foreach($modules as $module){
				$addToSave = true;
				foreach($dbModules as $dbModule){
					if(
						$module->module == $dbModule->module
						&& $module->position == $dbModule->position
					){
						$addToSave = false;
						break;
					}
				}
				if($addToSave){
					$modulesForSave[] = $module;
				}
			}


			foreach($dbModules as $dbModule){
				$addToDelete = true;
				if(in_array($dbModule->module, $moduleNamesExcludeToDelete)){
					$addToDelete = false;
				}

				foreach($modules as $module){
					if($dbModule->module == $module->module){
						$addToDelete = false;
					}
				}

				if($addToDelete){
					$moduleMenuIdsForDelete[] = $dbModule->moduleid;

					$menuIds = $repositoryModulesMenu->getModuleIdsByModuleId($dbModule->moduleid);
					if(isset($menuIds) && count($menuIds) == 1){
						$moduleIdsForDelete[] = $dbModule->moduleid;
					}
				}
			}

			if(count($moduleMenuIdsForDelete)){
				$repositoryModulesMenu->delete( array('moduleid' => $moduleMenuIdsForDelete, 'menuid' => $systemMenuItem->item_id) );
			}
			if(count($moduleIdsForDelete)){
				$tableModules = \JTable::getInstance('Module', 'JTable');
				foreach($moduleIdsForDelete as $moduleIdForDelete){
					$tableModules->delete($moduleIdForDelete);
				}
			}
		}

		if(is_array($modulesForSave) && count($modulesForSave)){
			$modelModule = new Module();

			foreach($modulesForSave as $module){
				$extention = $repositoryExtensions->getExtensionByElement($module->module);

				if(isset($extention->extension_id) && $extention->extension_id){
					$modelModule->setState('courseId', $this->getState('courseId'));
					$modelModule->setState('jextid', $extention->extension_id);
					$modelModule->setState('position', $module->position);
					$modelModule->setState('title', (isset($module->title) && $module->title ? $module->title : ''));

					$modelModule->save();
				}
			}
		}

		$this->saveProhibitedTools();
		$this->updateCourseParams();
	}

	public function saveProhibitedTools()
	{
		$teacherTools = $this->getProhibitedToolsByUserRole(1);
		$learnerTools = $this->getProhibitedToolsByUserRole(2);

		$teacherData = $this->prepareData($teacherTools);
		$learnerData = $this->prepareData($learnerTools);

		$data = array_merge($teacherData, $learnerData);
		if(isset($data) && is_array($data)){
			$resultDelete = $this->deleteProhibitedToolsForCourse();

			if($resultDelete && count($data)){
				return $this->repository->saveMultiple($data);
			}
		}
		return false;
	}

	public function deleteProhibitedToolsForCourse()
	{
		return $this->repository->delete(
			array(
				'course_id' => $this->getState('courseId')
			)
		);
	}

	protected function prepareData($toolList=array())
	{
		$data = array();
		if(count($toolList)){
			foreach($toolList as $tool){
				$item = array();
				$item['course_id'] = $this->getState('courseId');
				$item['menu_id'] = $tool->id;
				$item['user_access'] = $tool->user_access;
				$data[] = $item;
			}
		}
		return $data;
	}

	protected function getProhibitedToolsByUserRole($userRole=1)
	{
		$toolsList = $this->getAllToolsByUserRole($userRole);
		$allAvailableToolsArray = $this->getAllAvailableTools($userRole);

		if($userRole == 1){
			$excludeToolsIds = $this->getState('teacherCid', array());
		}
		if($userRole == 2){
			$excludeToolsIds = $this->getState('learnerCid', array());
		}

		$tools = array();
		foreach($toolsList as $tool){
			if(in_array($tool->lang_var, $allAvailableToolsArray) && !in_array($tool->id, $excludeToolsIds)){
				$tools[] = $tool;
			}
		}

		return $tools;
	}

	public function getSavedPatternId()
	{
		$repositoryCourse = ServiceLocator::get('repositoryCourse');
		$course = $repositoryCourse->getByID($this->getState('courseId'));

		$registry = new \JRegistry;
		$registry->loadString($course->params);

		return (int) $registry->get('pattern_id', 0);
	}

	public function getCurrentPatternId()
	{
		$savedPatternId = $this->getSavedPatternId();
		$patternId = $this->getState('patternId', 0);

		if($patternId){
			return (int) $patternId;
		} else
		if($savedPatternId){
			return (int) $savedPatternId;
		}
		return 1;
	}

	protected function getAllToolsByUserRole($userRole=1)
	{
		$repositoryLmsMenu = new Repositories\LmsMenu(array('db' => $this->_db));
		$toolsList = $repositoryLmsMenu->getByFilter(
			array(
				'published' => 1,
				'user_access' => $userRole,
				'is_separator' => 0,
				'list.ordering' => 'ordering',
				'list.direction' => 'ASC'
			)
		);

		$allAvailableToolsArray = $this->getAllAvailableTools($userRole);

		$tools = array();
		foreach($toolsList as $tool){
			if(in_array($tool->lang_var, $allAvailableToolsArray)){
				$tool->title = $tool->lang_var;
				$tools[] = $tool;
			}
		}
		return $tools;
	}

	public function getTools($userRole=1)
	{
		$jlmsConfig = ServiceLocator::get('config');
		$jlmsAcl = \JLMSFactory::getACL();

		$savedPatternId = $this->getSavedPatternId();

		$currentPatternId = $this->getCurrentPatternId();

//		echo '<pre>';
//		echo '$savedPatternId';
//		var_dump($savedPatternId);
//		echo '<br />';
//		echo '$currentPatternId';
//		var_dump($currentPatternId);
//		echo '</pre>';

		$toolsList = $this->getAllToolsByUserRole($userRole);

		$allAvailableToolsArray = $this->getAllAvailableTools($userRole);
		$patternAllowedToolsArray = $this->getPatternAllowedTools($userRole);

//		echo '<pre>';
//		print_r($patternAllowedToolsArray);
//		echo '</pre>';

		$prohibitedToolsList = $this->repository->getProhibitedTools($this->getState('courseId'), $userRole);
		$prohibitedToolsArray = array();
		foreach($prohibitedToolsList as $tool){
			if(in_array($tool->lang_var, $allAvailableToolsArray)){
				$prohibitedToolsArray[] = $tool->lang_var;
			}
		}

		$allowedToolsArray = array();
		if($currentPatternId == $savedPatternId && !$this->getState('reset', 0)){
			$allowedToolsArray = array_diff($allAvailableToolsArray, $prohibitedToolsArray);
		} else {
			$allowedToolsArray = array_intersect($allAvailableToolsArray, $patternAllowedToolsArray);
		}

		$tools = array();
		foreach($toolsList as $tool){
			$tool->disabled = 0;
			$tool->allowed = 0;
			$tool->iconSuffix = $this->getSuffixIconClass($tool->lang_var);

			if(count($allowedToolsArray) && in_array($tool->lang_var, $allowedToolsArray)){
				$tool->allowed = 1;
			}
			if($tool->lang_var == '_JLMS_TOOLBAR_GQP_PARENT'){
				$tool->allowed = 0;
				if($jlmsConfig->get('global_quest_pool', 0) && $jlmsAcl->isTeacher()){
					$tool->allowed = 1;
				}
			}
			if($tool->lang_var == '_JLMS_TOOLBAR_CEO_PARENT'){
				$tool->allowed = 0;
				if($jlmsConfig->get('is_user_parent', 0)){
					$tool->allowed = 1;
				}
			}
			if($tool->lang_var == '_JLMS_TOOLBAR_FORUM' && !$jlmsConfig->get('plugin_forum') && !$jlmsConfig->get('course_forum')){
				$tool->disabled = 1;
			}
			if($tool->lang_var == '_JLMS_TOOLBAR_CONF' && !$jlmsConfig->get('conference_enable')){
				$tool->disabled = 1;
			}
			if($tool->disabled){
				$tool->allowed = 0;
			}


			$tools[] = $tool;
		}

		return $tools;
	}

	public function getMainTools($userRole = 0)
	{
		$application = ServiceLocator::get('application');
		$juser = ServiceLocator::get('user');
		$jlmsConfig = ServiceLocator::get('config');
		$jlmsAcl = \JLMSFactory::getACL();

		$courseId = $this->getState('courseId', 0);
		$jlmsAcl->PrepareCourse($courseId);

		$toolsList = $this->getAllToolsByUserRole($userRole);

		$allAvailableToolsArray = $this->getAllAvailableTools($userRole);
		$toolsArray = $allAvailableToolsArray;

		$tools = array();
		foreach($toolsList as $tool){
			$tool->allowed = 0;
			$tool->iconSuffix = $this->getSuffixIconClass($tool->lang_var);

			if(in_array($tool->lang_var, $toolsArray)){
				$tool->allowed = 1;

				if($tool->lang_var == '_JLMS_TOOLBAR_GQP_PARENT'){
					$tool->allowed = 0;
					if($jlmsConfig->get('global_quest_pool', 0) && $jlmsAcl->isTeacher()){
						$tool->allowed = 1;
					}
				}

				if($tool->lang_var == '_JLMS_TOOLBAR_CEO_PARENT'){
					$tool->allowed = 0;
					if($jlmsConfig->get('is_user_parent', 0)){
						$tool->allowed = 1;
					}
				}

				//for guest users change icon to courses
				if($tool->lang_var == '_JLMS_TOOLBAR_HOME' && (!isset($juser->id) || !$juser->id)){
					$tool->title = '_JLMS_TOOLBAR_COURSES';
					$tool->iconSuffix = $this->getSuffixIconClass('_JLMS_TOOLBAR_COURSES');
				}
			}

			if($tool->allowed){
				$tools[] = $tool;
			}
		}

		$template = $application->getTemplate();
		if($jlmsAcl->isAdmin()){
			$jlmsConfig->set('show_statistics_reports', true);
		} else
		if($jlmsAcl->isTeacher()){
			$jlmsConfig->set('show_statistics_reports', true);
		} else
		if($jlmsAcl->isStaff()){
			$jlmsConfig->set('show_statistics_reports', true);
		} else {
			$jlmsConfig->set('show_statistics_reports', false);
		}
		if($template == 'joomlalms' && $jlmsConfig->get('show_statistics_reports', false)){
			$tools[] = $this->getReportsTool();
		}

//		if($jlmsAcl->CheckToolPermissions('user_settings')){
		if($courseId && ($jlmsAcl->isAdmin() || $jlmsAcl->isTeacher())){
			$tools[] = $this->getUserOptionsTool();
		}

		return $tools;
	}

	public function getUserOptionsTool()
	{
		$jlmsConfig = ServiceLocator::get('config');
		$jlmsAcl = \JLMSFactory::getACL();

		$tool = new \stdClass();
		$tool->lang_var = '_JLMS_TOOLBAR_USER_OPTIONS';
		$tool->title = $tool->lang_var;
		$tool->task = '';
		$tool->allowed = 1;
		$tool->userOption = 1;
		$tool->preTitle = '_JLMS_UO_SWITCH_TYPE';

		$currentUserType = $jlmsConfig->get('current_usertype');

		$tool->link = 'index.php?option=com_joomla_lms';
		if($currentUserType == 1){
			$tool->lang_var = '_JLMS_ROLE_STU';
			$tool->title = $tool->lang_var;
			$tool->link .= '&task=to_student';
			$tool->iconSuffix = 'students-role';
		} else
		if($currentUserType == 2){
			$tool->lang_var = '_JLMS_ROLE_TEACHER';
			$tool->title = $tool->lang_var;
			$tool->link .= '&task=to_teacher';
			$tool->iconSuffix = 'teachers-role';
		}
		$tool->link .= '&id='.$this->getState('courseId');
		$tool->link .= '&Itemid='.$jlmsConfig->get('Itemid');

		$tool->link = \JLMSRoute::_($tool->link);

		return $tool;
	}

	public function getReportsTool()
	{
		$tool = new \stdClass();
		$tool->lang_var = '_JLMS_REPORTS_MODULE';
		$tool->title = $tool->lang_var;
		$tool->task = '';
		$tool->allowed = 1;
		$tool->iconSuffix = $this->getSuffixIconClass($tool->lang_var);

		$tool->childTools = array();

		$childTool = new \stdClass();
		$childTool->lang_var = '_JLMS_REPORTS_ACCESS';
		$childTool->title = $childTool->lang_var;
		$childTool->task = 'report_access';
		$childTool->allowed = 1;
		$tool->childTools[] = $childTool;

		$childTool = new \stdClass();
		$childTool->lang_var = '_JLMS_REPORTS_CONCLUSION';
		$childTool->title = $childTool->lang_var;
		$childTool->task = 'report_certif';
		$childTool->allowed = 1;
		$tool->childTools[] = $childTool;

		$childTool = new \stdClass();
		$childTool->lang_var = '_JLMS_REPORTS_USER';
		$childTool->title = $childTool->lang_var;
		$childTool->task = 'report_grade';
		$childTool->allowed = 1;
		$tool->childTools[] = $childTool;

		return $tool;
	}

	public function getModules()
	{
		$currentPatternId = $this->getCurrentPatternId();
		$pattern = $this->getPatternById($currentPatternId);

		$repositoryExtensions = new Repositories\Extensions();

		$modules = array();
		if(isset($pattern->modules) && count($pattern->modules)){

			$client = \JApplicationHelper::getClientInfo(0);
			$lang = \JFactory::getLanguage();

			foreach($pattern->modules as $item){
				$extensionInfo = $repositoryExtensions->getExtensionByElement($item->module, 'module');

				if(isset($extensionInfo->extension_id) && $extensionInfo->extension_id){
					$lang->load($extensionInfo->element . '.sys', $client->path, null, false, true)
					|| $lang->load($extensionInfo->element . '.sys', $client->path . '/modules/' . $extensionInfo->element, null, false, true);

					$item->name = isset($item->title) && $item->title ? \JText::_($item->title) : \JText::_($extensionInfo->name);

					$modules[] = $item;
				}
			}
		}


		return $modules;
	}

	public function getAllowedTools($userRole=1)
	{
		$items = $this->getTools($userRole);

		$tools = array();
		foreach($items as $item){
			if($item->allowed){
				$tools[] = $item;
			}
		}
		return $tools;
	}

	public function getPatternById($patternId=1)
	{
		$patternList = $this->getPatternList();
		if(is_array($patternList) && count($patternList)){
			foreach($patternList as $pattern){
				if($pattern->id == $patternId){
					return $pattern;
					break;
				}
			}
		}
		return false;
	}

	protected function getPatternAllowedTools($userRole=1)
	{
		$currentPattern = $this->getPatternById($this->getCurrentPatternId());

		if($userRole == 1){
			return isset($currentPattern->tools->teacher) && is_array($currentPattern->tools->teacher) ? $currentPattern->tools->teacher : array();
		}
		if($userRole == 2){
			return isset($currentPattern->tools->learner) && is_array($currentPattern->tools->learner) ? $currentPattern->tools->learner : array();
		}

		return false;
	}

	private function generationJSONConfig($data = array(), $fileConfig = '')
	{
		if(is_array($data) && count($data)){
			$pathToFolderConfig = JPATH_SITE.'/components/com_joomla_lms/configs';
			if(!$fileConfig){
				$fileConfig = 'config.lms_learningpattern.json';
			}
			$pathToConfig = $pathToFolderConfig.'/'.$fileConfig;

			if(!file_exists($pathToConfig)){
				if(!file_exists($pathToFolderConfig)){
					\JFolder::create($pathToFolderConfig);
				}

				$fp = fopen($pathToConfig, 'w');
				fwrite($fp, json_encode($data));
				fclose($fp);
			}
		}
		return false;
	}

	private function loadJSONConfig($fileConfig='')
	{
		$pathToFolderConfig = JPATH_SITE.'/components/com_joomla_lms/configs';
		if(!$fileConfig){
			$fileConfig = 'config.lms_learningpattern.json';
		}
		$pathToConfig = $pathToFolderConfig.'/'.$fileConfig;

		if(file_exists($pathToConfig)){
			return json_decode(@file_get_contents($pathToConfig));
		} else {
			return array();
		}
	}

	public function getPatternSelectlist()
	{
		$patternList = $this->getPatternList();
		foreach($patternList as $pattern){
			$pattern->title = \JText::_($pattern->title);
		}

		/*
		$savedPatternId = $this->getSavedPatternId();
		foreach($patternList as $pattern){
			if($savedPatternId && $savedPatternId == $pattern->id && !$this->getState('reset')){
				$pattern->title .= ' '.'(current)';
			}
		}
		*/

		return $patternList;
	}

	public function getCurrentPattern()
	{
		return $this->getPatternById($this->getCurrentPatternId());
	}

	public function getPatternList()
	{
		$patternList = $this->loadJSONConfig();
		if(is_array($patternList) && count($patternList)){
			return $patternList;
		}

		######## Pattern 1 ########
		$pattern = new \stdClass();
		$pattern->id = 1;
		$pattern->title = '_JLMS_COURSEBUILDER_PATTERN_TITLE_DEFAULT';
		$pattern->description = '_JLMS_COURSEBUILDER_PATTERN_DESCRIPTION_DEFAULT';
		$pattern->tools = new \stdClass();

		$pattern->tools->teacher = array();
		$pattern->tools->teacher[] = '_JLMS_PATHWAY_COURSE_HOME';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_AGENDA';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_DOCS';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_LPATH';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_LINKS';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_QUIZZES';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_DROP';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_HOMEWORK';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_ATTEND';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_FORUM';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_CONF';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_CHAT';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_MAILBOX';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_GRADEBOOK';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_TRACK';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_USERS';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_HELP';

		$pattern->tools->learner = array();
		$pattern->tools->learner[] = '_JLMS_PATHWAY_COURSE_HOME';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_AGENDA';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_DOCS';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_LPATH';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_LINKS';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_QUIZZES';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_DROP';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_HOMEWORK';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_ATTEND';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_FORUM';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_CONF';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_CHAT';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_MAILBOX';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_GRADEBOOK';

		$modules = array();

		$module = new \stdClass();
		$module->module = 'mod_jlms_lpaths';
		$module->position = 'jlms-inline';
		$modules[] = $module;

		$module = new \stdClass();
		$module->module = 'mod_jlms_quizzes';
		$module->position = 'jlms-inline';
		$modules[] = $module;

		$module = new \stdClass();
		$module->module = 'mod_jlms_webinars';
		$module->position = 'jlms-inline';
		$modules[] = $module;

		$module = new \stdClass();
		$module->module = 'mod_custom';
		$module->position = 'jlms-inline';
		$modules[] = $module;

		$module = new \stdClass();
		$module->module = 'mod_jlms_course_teacher';
		$module->position = 'jlms-right';
		$modules[] = $module;

		$module = new \stdClass();
		$module->module = 'mod_jlms_upcoming_webinar';
		$module->position = 'jlms-right';
		$modules[] = $module;

		$pattern->modules = $modules;
		$patternList[] = $pattern;

		######## Pattern 2 ########
		$pattern = new \stdClass();
		$pattern->id = 2;
		$pattern->title = '_JLMS_COURSEBUILDER_PATTERN_TITLE_1';
		$pattern->description = '_JLMS_COURSEBUILDER_PATTERN_DESCRIPTION_1';
		$pattern->tools = new \stdClass();

		$pattern->tools->teacher = array();
		$pattern->tools->teacher[] = '_JLMS_PATHWAY_COURSE_HOME';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_AGENDA';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_DOCS';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_LPATH';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_LINKS';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_QUIZZES';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_DROP';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_HOMEWORK';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_ATTEND';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_FORUM';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_CONF';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_CHAT';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_MAILBOX';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_GRADEBOOK';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_TRACK';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_USERS';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_HELP';

		$pattern->tools->learner = array();
		$pattern->tools->learner[] = '_JLMS_PATHWAY_COURSE_HOME';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_AGENDA';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_DOCS';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_LPATH';

		$modules = array();

		$module = new \stdClass();
		$module->module = 'mod_custom';
		$module->position = 'jlms-inline';
		$modules[] = $module;

		$pattern->modules = $modules;
		$patternList[] = $pattern;

		######## Pattern 3 ########
		$pattern = new \stdClass();
		$pattern->id = 3;
		$pattern->title = '_JLMS_COURSEBUILDER_PATTERN_TITLE_2';
		$pattern->description = '_JLMS_COURSEBUILDER_PATTERN_DESCRIPTION_2';
		$pattern->tools = new \stdClass();

		$pattern->tools->teacher = array();
		$pattern->tools->teacher[] = '_JLMS_PATHWAY_COURSE_HOME';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_AGENDA';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_DOCS';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_LPATH';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_LINKS';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_QUIZZES';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_HOMEWORK';
		$pattern->tools->teacher[] = '_JLMS_TOOLBAR_GRADEBOOK';

		$pattern->tools->learner = array();
		$pattern->tools->learner[] = '_JLMS_PATHWAY_COURSE_HOME';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_AGENDA';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_DOCS';
		$pattern->tools->learner[] = '_JLMS_TOOLBAR_LPATH';

		$modules = array();

		$module = new \stdClass();
		$module->module = 'mod_custom';
		$module->position = 'jlms-inline';
		$modules[] = $module;

		$module = new \stdClass();
		$module->module = 'mod_jlms_course_teacher';
		$module->position = 'jlms-right';
		$modules[] = $module;

		$pattern->modules = $modules;
		$patternList[] = $pattern;

		$this->generationJSONConfig($patternList);

		return $patternList;
	}

	public function getSuffixIconClass($lang_var = '_JLMS_TOOLBAR_HOME')
	{
		$toolsSuffixClass = array(
			'_JLMS_TOOLBAR_HOME' => 'home',
			'_JLMS_TOOLBAR_COURSES' => 'courses',
			'_JLMS_TOOLBAR_LIBRARY' => 'file_library',
			'_JLMS_TOOLBAR_SUBSCRIPTIONS' => 'subscriptions',
			'_JLMS_TOOLBAR_CEO_PARENT' => 'superviser',
			'_JLMS_TOOLBAR_GQP_PARENT' => 'questions_pool',

			'_JLMS_REPORTS_MODULE' => 'reports',
//			'_JLMS_REPORTS_ACCESS' => 'attendance',
//			'_JLMS_REPORTS_CONCLUSION' => 'gradebook',
//			'_JLMS_REPORTS_USER' => 'users_management',

			'_JLMS_PATHWAY_COURSE_HOME' => 'course-home',
			'_JLMS_TOOLBAR_AGENDA' => 'announcements',
			'_JLMS_TOOLBAR_DOCS' => 'documents',
			'_JLMS_TOOLBAR_LPATH' => 'learning_path',
			'_JLMS_TOOLBAR_LINKS' => 'links',
			'_JLMS_TOOLBAR_QUIZZES' => 'quizzes',
			'_JLMS_TOOLBAR_DROP' => 'dropbox',
			'_JLMS_TOOLBAR_HOMEWORK' => 'assignments',
			'_JLMS_TOOLBAR_ATTEND' => 'attendance',
			'_JLMS_TOOLBAR_FORUM' => 'forum',
			'_JLMS_TOOLBAR_CONF' => 'webinars',
			'_JLMS_TOOLBAR_CHAT' => 'chat',
			'_JLMS_TOOLBAR_MAILBOX' => 'mailbox',
			'_JLMS_TOOLBAR_GRADEBOOK' => 'gradebook',

			'_JLMS_TOOLBAR_TRACK' => 'tracking',
			'_JLMS_TOOLBAR_USERS' => 'users_management',
			'_JLMS_TOOLBAR_USER_OPTIONS' => 'user',
			'_JLMS_TOOLBAR_HELP' => 'help',
		);

		return isset($toolsSuffixClass[$lang_var]) ? $toolsSuffixClass[$lang_var] : 'empty';
	}

	protected function getAllAvailableTools($userRole=1)
	{
		$tools = array();

		if($userRole == -1){
			$tools[] = '_JLMS_TOOLBAR_HOME';
			$tools[] = '_JLMS_TOOLBAR_SUBSCRIPTIONS';
		}

		if($userRole == 0){
			$tools[] = '_JLMS_TOOLBAR_HOME';
			$tools[] = '_JLMS_TOOLBAR_COURSES';
			$tools[] = '_JLMS_TOOLBAR_LIBRARY';
			$tools[] = '_JLMS_TOOLBAR_SUBSCRIPTIONS';
			$tools[] = '_JLMS_TOOLBAR_CEO_PARENT';
			$tools[] = '_JLMS_TOOLBAR_GQP_PARENT';
		}

		if($userRole == 1 || $userRole == 2){
			$tools[] = '_JLMS_PATHWAY_COURSE_HOME';
			$tools[] = '_JLMS_TOOLBAR_AGENDA';
			$tools[] = '_JLMS_TOOLBAR_DOCS';
			$tools[] = '_JLMS_TOOLBAR_LPATH';
			$tools[] = '_JLMS_TOOLBAR_LINKS';
			$tools[] = '_JLMS_TOOLBAR_QUIZZES';
//			$tools[] = '_JLMS_TOOLBAR_DROP';
			$tools[] = '_JLMS_TOOLBAR_HOMEWORK';
			$tools[] = '_JLMS_TOOLBAR_ATTEND';
//			$tools[] = '_JLMS_TOOLBAR_FORUM';
			$tools[] = '_JLMS_TOOLBAR_CONF';
			$tools[] = '_JLMS_TOOLBAR_CHAT';
			$tools[] = '_JLMS_TOOLBAR_MAILBOX';
			$tools[] = '_JLMS_TOOLBAR_GRADEBOOK';
		}

		if($userRole == 1){
			$tools[] = '_JLMS_TOOLBAR_TRACK';
			$tools[] = '_JLMS_TOOLBAR_USERS';
//			$tools[] = '_JLMS_TOOLBAR_USER_OPTIONS';
			$tools[] = '_JLMS_TOOLBAR_HELP';
		}

		return $tools;
	}
}