<?php
namespace LMS\Tools\Coursebuilder\Model;

use LMS\Libraries\Base;
use LMS\Libraries\ServiceLocator;
use LMS\Tools\Coursebuilder\Repositories;

defined('_JEXEC') or die;

class Module extends Base\Model
{
	protected $name = 'Module';
	
	protected $helpURL = '';
	
	protected $helpKey = '';	

	public function __construct($options = array())
	{
		parent::__construct($options);
		$this->modelDir = __DIR__;

		$this->repositoryExtensions = new Repositories\Extensions(array('db' => $this->_db));
		$this->repositoryModules = new Repositories\Modules(array('db' => $this->_db));
		$this->repositoryModulesMenu = new Repositories\ModulesMenu(array('db' => $this->_db));
		$this->repositorySystemMenu = new Repositories\SystemMenu(array('db' => $this->_db));
	}

	public function save()
	{
		$jextid = $this->getState('jextid', 0);
		$position = $this->getState('position', '');
		$title = $this->getState('title', '');

		$data = $this->getState('data', array());
		$data['id'] = $this->getState('id', 0);

		$repositoryModulesMenu = new Repositories\ModulesMenu(array('db' => \JFactory::getDbo()));

		$tableModules = \JTable::getInstance('Module', 'JTable');

		if(isset($data['id']) && $data['id']){
			$tableModules->save($data);
		} else {
			$extension = $this->repositoryExtensions->getByID($jextid);

			if(isset($extension->extension_id) && $extension->extension_id){

				$allowincoursebuilder = false;
				$singleinstance = false;

				$jlmsModuleParam = \LMS\Tools\Coursebuilder\Helpers\Module::getJlmsModuleParams($extension->element);
				$allowincoursebuilder = isset($jlmsModuleParam->allowincoursebuilder) ? (bool) (int) $jlmsModuleParam->allowincoursebuilder : false;
				$singleinstance = isset($jlmsModuleParam->singleinstance) ? (bool) (int) $jlmsModuleParam->singleinstance : false;

				$existModules = array();
				if($singleinstance){
					$existModules = $this->repositoryModules->getModuleByModuleAndPosition($extension->element, $position);
				}

				$resultModuleId = null;
				if(is_array($existModules) && count($existModules)){
					foreach($existModules as $existModule){
						if($existModule->position == $position){
							$resultModuleId = $existModule->id;
							break;
						}
					}
				}

				if(is_null($resultModuleId)){
					$enabledAdd = true;
					if(in_array($this->getState('position'), array('jlms-right'))){
						if(in_array($extension->element, array('mod_jlms_lpaths', 'mod_jlms_quizzes'))){
							$enabledAdd = false;
						}
					}

					if($enabledAdd){
						//load language file
						$client = \JApplicationHelper::getClientInfo(0);

						$lang = \JFactory::getLanguage();
						$lang->load($extension->element . '.sys', $client->path, null, false, true)
						|| $lang->load($extension->element . '.sys', $client->path . '/modules/' . $extension->element, null, false, true);

						$maxOrdering = $this->repositoryModules->getMaxOrdering($position, 1);
						$ordering = $maxOrdering + 1;

						$data = $tableModules->getProperties(1);
						$data['title'] = $title ? \JText::_($title) : \JText::_($extension->name);
						$data['content'] = '';
						$data['module'] = $extension->element;
						$data['position'] = trim($position);
						$data['client_id'] = 0;
						$data['ordering'] = $ordering;
						$data['published'] = 1;
						$data['showtitle'] = 1;
						$data['language'] = '*';

						$params = new \JRegistry();
						$params->set('prepare_content', 1);
						$data['params'] = $params->toString();

						$tableModules->save($data);
						$resultModuleId = $tableModules->id;
					}
				}
				
				if(isset($resultModuleId) && $resultModuleId){

					$systemMenuItem = $this->repositorySystemMenu->getJlmsSystemMenuItemByCourseId($this->getState('courseId'));

					if(isset($systemMenuItem) && $systemMenuItem->id){
						$moduleMenuData = array();
						$moduleMenuData['moduleid'] = $resultModuleId;
						$moduleMenuData['menuid'] = $systemMenuItem->item_id;

						$resultModuleMenuId = $repositoryModulesMenu->save($moduleMenuData);
					}
				}
			}
		}
	}

	public function getItem()
	{
		$pk = (!empty($pk)) ? (int) $pk : (int) $this->getState('id');		
		
		if (!isset($this->_cache[$pk]))
		{			
			$module = $this->repositoryModules->getByID($pk);
						
			if (empty($pk))
			{					
				if ($extensionId = (int) $this->getState('extension.id'))
				{
					$extension = $this->repositoryExtensions->getByID($extensionId);				

					if (empty($extension))
					{
						$this->setError('COM_MODULES_ERROR_CANNOT_FIND_MODULE');

						return false;
					}

					$module->module    = $extension->element;
					$module->client_id = $extension->client_id;
				}				
			}
			
			$properties = get_object_vars($module);			
								
			$this->_cache[$pk] = (object) $properties;

			$registry = new \JRegistry;
			$registry->loadString($module->params);
			$this->_cache[$pk]->params = $registry->toArray();		
						
			$client = \JApplicationHelper::getClientInfo($module->client_id);
			$path   = \JPath::clean($client->path . '/modules/' . $module->module . '/' . $module->module . '.xml');

			if (file_exists($path))
			{
				$this->_cache[$pk]->xml = simplexml_load_file($path);
			}
			else
			{
				$this->_cache[$pk]->xml = null;
			}
		}

		return $this->_cache[$pk];
	}
	
	protected function loadFormData()
	{
		return $this->getItem();
	}
	
	protected function preprocessForm(\JForm $form, $data, $group = 'content')
	{
		jimport('joomla.filesystem.path');

		$lang = \JFactory::getLanguage();
		$item = $this->getItem();
		$clientId = $item->client_id;
		$module = $item->module;
		
		$client   = \JApplicationHelper::getClientInfo($clientId);
		$formFile = \JPath::clean($client->path . '/modules/' . $module . '/' . $module . '.xml');

		// Load the core and/or local language file(s).
		$lang->load($module, $client->path, null, false, true)
		||	$lang->load($module, $client->path . '/modules/' . $module, null, false, true);

		if (file_exists($formFile))
		{
			// Get the module form.
			if (!$form->loadFile($formFile, false, '//config'))
			{
				throw new Exception(JText::_('JERROR_LOADFILE_FAILED'));
			}

			// Attempt to load the xml file.
			if (!$xml = simplexml_load_file($formFile))
			{
				throw new Exception(JText::_('JERROR_LOADFILE_FAILED'));
			}

			// Get the help data from the XML file if present.
			$help = $xml->xpath('/extension/help');

			if (!empty($help))
			{
				$helpKey = trim((string) $help[0]['key']);
				$helpURL = trim((string) $help[0]['url']);

				$this->helpKey = $helpKey ? $helpKey : $this->helpKey;
				$this->helpURL = $helpURL ? $helpURL : $this->helpURL;
			}
		}
		
		// Load the default advanced params
		\JForm::addFormPath(JPATH_SITE . '/com_joomla_lms/tools/coursebuilder/models/forms/');
		$form->loadFile('module', false);		

		// Trigger the default form events.
		parent::preprocessForm($form, $data, $group);
	}

	public function remove()
	{
		$courseId = $this->getState('courseId', 0);
		$id = $this->getState('id', 0);

		$tableModules = \JTable::getInstance('Module', 'JTable');

		if($courseId){
			$systemMenuItem = $this->repositorySystemMenu->getJlmsSystemMenuItemByCourseId($courseId);
			if(isset($systemMenuItem->item_id) && $systemMenuItem->item_id){
				$this->repositoryModulesMenu->delete(array('moduleid' => $id, 'menuid' => $systemMenuItem->item_id));
				$tableModules->delete($id);
			}
		}
	}	
}