<?php
namespace LMS\Tools\Coursebuilder\Model;

use LMS\Libraries\Base;
use LMS\Libraries\ServiceLocator;
use LMS\Tools\Coursebuilder\Repositories;

defined('_JEXEC') or die;


class Modules extends Base\Model
{
	protected $name = 'Modules';

	public function __construct($options)
	{
		parent::__construct($options);
		$this->modelDir = __DIR__;
		$this->repository = isset($options['repository']) ? $options['repository'] : new Repositories\Extensions(array('db' => $this->_db));
	}

	public function getItems()
	{
		$items = $this->repository->getByFilter(
			array(
				'fields' => $this->repository->getTable()->getTableAlias().'.*, '.$this->repository->getTable()->getTableAlias().'.element as module',
				'type' => $this->getState('type'),
				'client_id' => $this->getState('clientId'),
				'enabled' => $this->getState('enabled'),
			)
		);

		if(isset($items) && is_array($items) && count($items)){
			$itemsTemp = array();
			foreach ($items as $item){
				$jlmsModuleParam = \LMS\Tools\Coursebuilder\Helpers\Module::getJlmsModuleParams($item->module);
				$allowincoursebuilder = isset($jlmsModuleParam->allowincoursebuilder) ? (bool) (int) $jlmsModuleParam->allowincoursebuilder : false;
				$singleinstance = isset($jlmsModuleParam->singleinstance) ? (bool) (int) $jlmsModuleParam->singleinstance : false;

				if($allowincoursebuilder){
					$enabledAdd = true;
					if($singleinstance){
						$repositoryModules = new Repositories\Modules(array('db' => $this->_db));
						$repositoryModulesMenu = new Repositories\ModulesMenu(array('db' => $this->_db));
						$repositorySystemMenu = new Repositories\SystemMenu(array('db' => $this->_db));

						$existModules = $repositoryModules->getModuleByModule($item->module);
						$systemMenuItem = $repositorySystemMenu->getJlmsSystemMenuItemByCourseId($this->getState('courseId'));

						if(is_array($existModules) && count($existModules)){
							foreach($existModules as $module){
								$records = $repositoryModulesMenu->getRecordsByModuleidAndItemid($module->id, $systemMenuItem->item_id);
								if(is_array($records) && count($records)){
									$enabledAdd = false;
									break;
								}
							}
						}
					}

					if(in_array($this->getState('position'), array('jlms-right'))){
						if(in_array($item->module, array('mod_jlms_lpaths', 'mod_jlms_quizzes'))){
							$enabledAdd = false;
						}
					}

					if($enabledAdd){
						$itemsTemp[] = $item;
					}
				}
			}
			if(count($itemsTemp)){
				$items = $itemsTemp;
			}
		}

		if(isset($items) && is_array($items) && count($items)){
			$client = \JApplicationHelper::getClientInfo(0);
			$lang = \JFactory::getLanguage();

			foreach ($items as &$item)
			{
				$path = \JPath::clean($client->path . '/modules/' . $item->module . '/' . $item->module . '.xml');
				if (file_exists($path))
				{
					$item->xml = simplexml_load_file($path);
				}
				else
				{
					$item->xml = null;
				}

				// 1.5 Format; Core files or language packs then
				// 1.6 3PD Extension Support
				$lang->load($item->module . '.sys', $client->path, null, false, true)
				|| $lang->load($item->module . '.sys', $client->path . '/modules/' . $item->module, null, false, true);
				$item->name = \JText::_($item->name);

				if (isset($item->xml) && $text = trim($item->xml->description))
				{
					$item->desc = \JText::_($text);
				}
				else
				{
					$item->desc = \JText::_('COM_MODULES_NODESCRIPTION');
				}
			}
			$items = \JArrayHelper::sortObjects($items, 'name', 1, true, true);
		}

		return $items;
	}

	public function saveorder($pks = null, $order = null)
	{
		$repositoryModules = new Repositories\Modules(array('db' => $this->_db));
		foreach ($pks as $i => $pk)
		{
			$item = $repositoryModules->getByID((int) $pk);
			if($item->ordering != $order[$i]){
				$data = array();
				$data['ordering'] = $order[$i];

				$conditions = array();
				$conditions['id'] = $pk;

				$repositoryModules->update($data, $conditions);
			}
		}
		return true;
	}
}